@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: Handler class for SPF
-our $VERSION = '3.20220914'; # VERSION
+our $VERSION = '3.20221006'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
 use Mail::SPF;
 
@@ -177,7 +177,7 @@ sub envfrom_callback {
         $self->{'dmarc_scope'}  = $scope;
         $self->{'dmarc_result'} = $result_code;
 
-        $self->dbgout( 'SPFCode', $result_code, LOG_INFO );
+        $self->dbgout( 'SPFCode', $result_code, LOG_DEBUG );
 
         if ( !( $config->{'hide_received-spf_header'} ) ) {
             if ( !( $config->{'hide_none'} && $result_code eq 'none' ) ) {
@@ -223,7 +223,7 @@ Mail::Milter::Authentication::Handler::SPF - Handler class for SPF
 
 =head1 VERSION
 
-version 3.20220914
+version 3.20221006
 
 =head1 DESCRIPTION
 
