@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: Handler class for SenderID
-our $VERSION = '3.20220914'; # VERSION
+our $VERSION = '3.20221006'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
 use Mail::Milter::Authentication::Handler::SPF;
 use Mail::SPF;
@@ -99,7 +99,7 @@ sub eoh_callback {
 
         my $result_code = $spf_result->code();
         $self->metric_count( 'senderid_total',  {'result' => $result_code } );
-        $self->dbgout( 'SenderIdCode', $result_code, LOG_INFO );
+        $self->dbgout( 'SenderIdCode', $result_code, LOG_DEBUG );
 
         if ( ! ( $config->{'hide_none'} && $result_code eq 'none' ) ) {
             my $auth_header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'senderid' )->safe_set_value( $result_code );
@@ -142,7 +142,7 @@ Mail::Milter::Authentication::Handler::SenderID - Handler class for SenderID
 
 =head1 VERSION
 
-version 3.20220914
+version 3.20221006
 
 =head1 DESCRIPTION
 
