@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: SMTP protocol handling
-our $VERSION = '3.20220914'; # VERSION
+our $VERSION = '3.20221006'; # VERSION
 use Digest::MD5 qw{ md5_hex };
 use Email::Date::Format qw{ email_date };
 use IO::Socket::INET;
@@ -60,7 +60,7 @@ sub smtp_init {
     $handler->set_symbol( 'C', 'i', $self->smtp_queue_id() );
 
     $smtp->{'count'}++ ;
-    $handler->dbgout( 'SMTP Transaction count', $self->{'count'} . '.' . $smtp->{'count'} , LOG_INFO );
+    $handler->dbgout( 'SMTP Transaction count', $self->{'count'} . '.' . $smtp->{'count'} , LOG_DEBUG );
 
     $smtp->{'init_required'} = 0;
 }
@@ -1111,7 +1111,7 @@ Mail::Milter::Authentication::Protocol::SMTP - SMTP protocol handling
 
 =head1 VERSION
 
-version 3.20220914
+version 3.20221006
 
 =head1 SYNOPSIS
 
